"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def add(
    hub,
    ctx,
    account_id: str,
    cluster_identifier: str,
    database_name: str,
    partner_name: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a partner integration to a cluster. This operation authorizes a partner to push status updates for the specified database. To complete the integration, you also set up the integration on the partner website.

    Args:
        account_id(str): The Amazon Web Services account ID that owns the cluster.
        cluster_identifier(str): The cluster identifier of the cluster that receives data from the partner.
        database_name(str): The name of the database that receives data from the partner.
        partner_name(str): The name of the partner that is authorized to send data.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.partner.init.add(
                ctx,
                account_id=value,
                cluster_identifier=value,
                database_name=value,
                partner_name=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.partner.init.add account_id=value, cluster_identifier=value, database_name=value, partner_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="add_partner",
        op_kwargs={
            "AccountId": account_id,
            "ClusterIdentifier": cluster_identifier,
            "DatabaseName": database_name,
            "PartnerName": partner_name,
        },
    )


async def delete(
    hub,
    ctx,
    account_id: str,
    cluster_identifier: str,
    database_name: str,
    partner_name: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a partner integration from a cluster. Data can still flow to the cluster until the integration is deleted at the partner's website.

    Args:
        account_id(str): The Amazon Web Services account ID that owns the cluster.
        cluster_identifier(str): The cluster identifier of the cluster that receives data from the partner.
        database_name(str): The name of the database that receives data from the partner.
        partner_name(str): The name of the partner that is authorized to send data.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.partner.init.delete(
                ctx,
                account_id=value,
                cluster_identifier=value,
                database_name=value,
                partner_name=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.partner.init.delete account_id=value, cluster_identifier=value, database_name=value, partner_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="delete_partner",
        op_kwargs={
            "AccountId": account_id,
            "ClusterIdentifier": cluster_identifier,
            "DatabaseName": database_name,
            "PartnerName": partner_name,
        },
    )


async def describe_all(
    hub,
    ctx,
    account_id: str,
    cluster_identifier: str,
    database_name: str = None,
    partner_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the partner integrations defined for a cluster.

    Args:
        account_id(str): The Amazon Web Services account ID that owns the cluster.
        cluster_identifier(str): The cluster identifier of the cluster whose partner integration is being described.
        database_name(str, optional): The name of the database whose partner integration is being described. If database name is not specified, then all databases in the cluster are described. Defaults to None.
        partner_name(str, optional): The name of the partner that is being described. If partner name is not specified, then all partner integrations are described. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.partner.init.describe_all(
                ctx, account_id=value, cluster_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.partner.init.describe_all account_id=value, cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_partners",
        op_kwargs={
            "AccountId": account_id,
            "ClusterIdentifier": cluster_identifier,
            "DatabaseName": database_name,
            "PartnerName": partner_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, placement_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information, including current status, about a game session placement request.  To get game session placement details, specify the placement ID. If successful, a GameSessionPlacement object is returned.  Related actions   CreateGameSession | DescribeGameSessions | DescribeGameSessionDetails | SearchGameSessions | UpdateGameSession | GetGameSessionLogUrl | StartGameSessionPlacement | DescribeGameSessionPlacement | StopGameSessionPlacement | All APIs by task

    Args:
        placement_id(str): A unique identifier for a game session placement to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.session.placement.describe(
                ctx, placement_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.session.placement.describe placement_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_game_session_placement",
        op_kwargs={"PlacementId": placement_id},
    )


async def start(
    hub,
    ctx,
    placement_id: str,
    game_session_queue_name: str,
    maximum_player_session_count: int,
    game_properties: List = None,
    game_session_name: str = None,
    player_latencies: List = None,
    desired_player_sessions: List = None,
    game_session_data: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Places a request for a new game session in a queue (see CreateGameSessionQueue). When processing a placement request, Amazon GameLift searches for available resources on the queue's destinations, scanning each until it finds resources or the placement request times out. A game session placement request can also request player sessions. When a new game session is successfully created, Amazon GameLift creates a player session for each player included in the request. When placing a game session, by default Amazon GameLift tries each fleet in the order they are listed in the queue configuration. Ideally, a queue's destinations are listed in preference order. Alternatively, when requesting a game session with players, you can also provide latency data for each player in relevant Regions. Latency data indicates the performance lag a player experiences when connected to a fleet in the Region. Amazon GameLift uses latency data to reorder the list of destinations to place the game session in a Region with minimal lag. If latency data is provided for multiple players, Amazon GameLift calculates each Region's average lag for all players and reorders to get the best game play across all players.  To place a new game session request, specify the following:   The queue name and a set of game session properties and settings   A unique ID (such as a UUID) for the placement. You use this ID to track the status of the placement request   (Optional) A set of player data and a unique player ID for each player that you are joining to the new game session (player data is optional, but if you include it, you must also provide a unique ID for each player)   Latency data for all players (if you want to optimize game play for the players)   If successful, a new game session placement is created. To track the status of a placement request, call DescribeGameSessionPlacement and check the request's status. If the status is FULFILLED, a new game session has been created and a game session ARN and Region are referenced. If the placement request times out, you can resubmit the request or retry it with a different queue.   Related actions   CreateGameSession | DescribeGameSessions | DescribeGameSessionDetails | SearchGameSessions | UpdateGameSession | GetGameSessionLogUrl | StartGameSessionPlacement | DescribeGameSessionPlacement | StopGameSessionPlacement | All APIs by task

    Args:
        placement_id(str): A unique identifier to assign to the new game session placement. This value is developer-defined. The value must be unique across all Regions and cannot be reused unless you are resubmitting a canceled or timed-out placement request.
        game_session_queue_name(str): Name of the queue to use to place the new game session. You can use either the queue name or ARN value. .
        game_properties(List, optional): A set of custom properties for a game session, formatted as key:value pairs. These properties are passed to a game server process in the GameSession object with a request to start a new game session (see Start a Game Session). Defaults to None.
        maximum_player_session_count(int): The maximum number of players that can be connected simultaneously to the game session.
        game_session_name(str, optional): A descriptive label that is associated with a game session. Session names do not need to be unique. Defaults to None.
        player_latencies(List, optional): A set of values, expressed in milliseconds, that indicates the amount of latency that a player experiences when connected to AWS Regions. This information is used to try to place the new game session where it can offer the best possible gameplay experience for the players. . Defaults to None.
        desired_player_sessions(List, optional): Set of information on each player to create a player session for. Defaults to None.
        game_session_data(str, optional): A set of custom game session properties, formatted as a single string value. This data is passed to a game server process in the GameSession object with a request to start a new game session (see Start a Game Session). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.session.placement.start(
                ctx,
                placement_id=value,
                game_session_queue_name=value,
                maximum_player_session_count=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.session.placement.start placement_id=value, game_session_queue_name=value, maximum_player_session_count=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="start_game_session_placement",
        op_kwargs={
            "PlacementId": placement_id,
            "GameSessionQueueName": game_session_queue_name,
            "GameProperties": game_properties,
            "MaximumPlayerSessionCount": maximum_player_session_count,
            "GameSessionName": game_session_name,
            "PlayerLatencies": player_latencies,
            "DesiredPlayerSessions": desired_player_sessions,
            "GameSessionData": game_session_data,
        },
    )


async def stop(hub, ctx, placement_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels a game session placement that is in PENDING status. To stop a placement, provide the placement ID values. If successful, the placement is moved to CANCELLED status.  Related actions   CreateGameSession | DescribeGameSessions | DescribeGameSessionDetails | SearchGameSessions | UpdateGameSession | GetGameSessionLogUrl | StartGameSessionPlacement | DescribeGameSessionPlacement | StopGameSessionPlacement | All APIs by task

    Args:
        placement_id(str): A unique identifier for a game session placement to cancel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.session.placement.stop(ctx, placement_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.session.placement.stop placement_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="stop_game_session_placement",
        op_kwargs={"PlacementId": placement_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub,
    ctx,
    fleet_id: str,
    start_time: str,
    dry_run: bool = None,
    event_type: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the events for the specified EC2 Fleet during the specified time. EC2 Fleet events are delayed by up to 30 seconds before they can be described. This ensures that you can query by the last evaluated time and not miss a recorded event. EC2 Fleet events are available for 48 hours. For more information, see Monitoring your EC2 Fleet in the Amazon EC2 User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        event_type(str, optional): The type of events to describe. By default, all events are described. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Specify a value between 1 and 1000. The default value is 1000. To retrieve the remaining results, make another call with the returned NextToken value. Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.
        fleet_id(str): The ID of the EC2 Fleet.
        start_time(str): The start date and time for the events, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.fleet.history.describe(
                ctx, fleet_id=value, start_time=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.fleet.history.describe fleet_id=value, start_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_fleet_history",
        op_kwargs={
            "DryRun": dry_run,
            "EventType": event_type,
            "MaxResults": max_results,
            "NextToken": next_token,
            "FleetId": fleet_id,
            "StartTime": start_time,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def admin(
    hub, ctx, user_pool_id: str, username: str, event_id: str, feedback_value: str
) -> Dict:
    r"""
    **Autogenerated function**

    Provides feedback for an authentication event as to whether it was from a valid user. This feedback is used for improving the risk evaluation decision for the user pool as part of Amazon Cognito advanced security.

    Args:
        user_pool_id(str): The user pool ID.
        username(str): The user pool username.
        event_id(str): The authentication event ID.
        feedback_value(str): The authentication event feedback value.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.update.auth_event_feedback.admin(
                ctx, user_pool_id=value, username=value, event_id=value, feedback_value=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.update.auth_event_feedback.admin user_pool_id=value, username=value, event_id=value, feedback_value=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="admin_update_auth_event_feedback",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "Username": username,
            "EventId": event_id,
            "FeedbackValue": feedback_value,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "type"


async def create(
    hub,
    ctx,
    slot_type_name: str,
    value_selection_setting: Dict,
    bot_id: str,
    bot_version: str,
    locale_id: str,
    description: str = None,
    slot_type_values: List = None,
    parent_slot_type_signature: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a custom slot type  To create a custom slot type, specify a name for the slot type and a set of enumeration values, the values that a slot of this type can assume.

    Args:
        slot_type_name(str): The name for the slot. A slot type name must be unique within the account.
        description(str, optional): A description of the slot type. Use the description to help identify the slot type in lists. Defaults to None.
        slot_type_values(List, optional): A list of SlotTypeValue objects that defines the values that the slot type can take. Each value can have a list of synonyms, additional values that help train the machine learning model about the values that it resolves for a slot. Defaults to None.
        value_selection_setting(Dict): Determines the strategy that Amazon Lex uses to select a value from the list of possible values. The field can be set to one of the following values:    OriginalValue - Returns the value entered by the user, if the user value is similar to the slot value.    TopResolution - If there is a resolution list for the slot, return the first value in the resolution list. If there is no resolution list, return null.   If you don't specify the valueSelectionSetting parameter, the default is OriginalValue.
        parent_slot_type_signature(str, optional): The built-in slot type used as a parent of this slot type. When you define a parent slot type, the new slot type has the configuration of the parent slot type. Only AMAZON.AlphaNumeric is supported. Defaults to None.
        bot_id(str): The identifier of the bot associated with this slot type.
        bot_version(str): The identifier of the bot version associated with this slot type.
        locale_id(str): The identifier of the language and locale that the slot type will be used in. The string must match one of the supported locales. All of the bots, intents, and slots used by the slot type must have the same locale. For more information, see Supported languages.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.slot.type_.create(
                ctx,
                slot_type_name=value,
                value_selection_setting=value,
                bot_id=value,
                bot_version=value,
                locale_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.slot.type.create slot_type_name=value, value_selection_setting=value, bot_id=value, bot_version=value, locale_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="create_slot_type",
        op_kwargs={
            "slotTypeName": slot_type_name,
            "description": description,
            "slotTypeValues": slot_type_values,
            "valueSelectionSetting": value_selection_setting,
            "parentSlotTypeSignature": parent_slot_type_signature,
            "botId": bot_id,
            "botVersion": bot_version,
            "localeId": locale_id,
        },
    )


async def delete(
    hub,
    ctx,
    slot_type_id: str,
    bot_id: str,
    bot_version: str,
    locale_id: str,
    skip_resource_in_use_check: bool = None,
) -> None:
    r"""
    **Autogenerated function**

    Deletes a slot type from a bot locale. If a slot is using the slot type, Amazon Lex throws a ResourceInUseException exception. To avoid the exception, set the skipResourceInUseCheck parameter to true.

    Args:
        slot_type_id(str): The identifier of the slot type to delete.
        bot_id(str): The identifier of the bot associated with the slot type.
        bot_version(str): The version of the bot associated with the slot type.
        locale_id(str): The identifier of the language and locale that the slot type will be deleted from. The string must match one of the supported locales. For more information, see Supported languages.
        skip_resource_in_use_check(bool, optional): By default, the DeleteSlotType operations throws a ResourceInUseException exception if you try to delete a slot type used by a slot. Set the skipResourceInUseCheck parameter to true to skip this check and remove the slot type even if a slot uses it. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.slot.type_.delete(
                ctx, slot_type_id=value, bot_id=value, bot_version=value, locale_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.slot.type.delete slot_type_id=value, bot_id=value, bot_version=value, locale_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="delete_slot_type",
        op_kwargs={
            "slotTypeId": slot_type_id,
            "botId": bot_id,
            "botVersion": bot_version,
            "localeId": locale_id,
            "skipResourceInUseCheck": skip_resource_in_use_check,
        },
    )


async def describe(
    hub, ctx, slot_type_id: str, bot_id: str, bot_version: str, locale_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Gets metadata information about a slot type.

    Args:
        slot_type_id(str): The identifier of the slot type.
        bot_id(str): The identifier of the bot associated with the slot type.
        bot_version(str): The version of the bot associated with the slot type.
        locale_id(str): The identifier of the language and locale of the slot type to describe. The string must match one of the supported locales. For more information, see Supported languages.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.slot.type_.describe(
                ctx, slot_type_id=value, bot_id=value, bot_version=value, locale_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.slot.type.describe slot_type_id=value, bot_id=value, bot_version=value, locale_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="describe_slot_type",
        op_kwargs={
            "slotTypeId": slot_type_id,
            "botId": bot_id,
            "botVersion": bot_version,
            "localeId": locale_id,
        },
    )


async def list_all(
    hub,
    ctx,
    bot_id: str,
    bot_version: str,
    locale_id: str,
    sort_by: Dict = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of slot types that match the specified criteria.

    Args:
        bot_id(str): The unique identifier of the bot that contains the slot types.
        bot_version(str): The version of the bot that contains the slot type.
        locale_id(str): The identifier of the language and locale of the slot types to list. The string must match one of the supported locales. For more information, see Supported languages.
        sort_by(Dict, optional): Determines the sort order for the response from the ListSlotTypes operation. You can choose to sort by the slot type name or last updated date in either ascending or descending order. Defaults to None.
        filters(List, optional): Provides the specification of a filter used to limit the slot types in the response to only those that match the filter specification. You can only specify one filter and only one string to filter on. Defaults to None.
        max_results(int, optional): The maximum number of slot types to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned. Defaults to None.
        next_token(str, optional): If the response from the ListSlotTypes operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.slot.type_.list_all(
                ctx, bot_id=value, bot_version=value, locale_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.slot.type.list_all bot_id=value, bot_version=value, locale_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="list_slot_types",
        op_kwargs={
            "botId": bot_id,
            "botVersion": bot_version,
            "localeId": locale_id,
            "sortBy": sort_by,
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    slot_type_id: str,
    slot_type_name: str,
    value_selection_setting: Dict,
    bot_id: str,
    bot_version: str,
    locale_id: str,
    description: str = None,
    slot_type_values: List = None,
    parent_slot_type_signature: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the configuration of an existing slot type.

    Args:
        slot_type_id(str): The unique identifier of the slot type to update.
        slot_type_name(str): The new name of the slot type.
        description(str, optional): The new description of the slot type. Defaults to None.
        slot_type_values(List, optional): A new list of values and their optional synonyms that define the values that the slot type can take. Defaults to None.
        value_selection_setting(Dict): The strategy that Amazon Lex should use when deciding on a value from the list of slot type values.
        parent_slot_type_signature(str, optional): The new built-in slot type that should be used as the parent of this slot type. Defaults to None.
        bot_id(str): The identifier of the bot that contains the slot type.
        bot_version(str): The version of the bot that contains the slot type. Must be DRAFT.
        locale_id(str): The identifier of the language and locale that contains the slot type. The string must match one of the supported locales. For more information, see Supported languages.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.slot.type_.update(
                ctx,
                slot_type_id=value,
                slot_type_name=value,
                value_selection_setting=value,
                bot_id=value,
                bot_version=value,
                locale_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.slot.type.update slot_type_id=value, slot_type_name=value, value_selection_setting=value, bot_id=value, bot_version=value, locale_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="update_slot_type",
        op_kwargs={
            "slotTypeId": slot_type_id,
            "slotTypeName": slot_type_name,
            "description": description,
            "slotTypeValues": slot_type_values,
            "valueSelectionSetting": value_selection_setting,
            "parentSlotTypeSignature": parent_slot_type_signature,
            "botId": bot_id,
            "botVersion": bot_version,
            "localeId": locale_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, name: str, description: str, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a custom action target in Security Hub. You can use custom actions on findings and insights in Security Hub to trigger target actions in Amazon CloudWatch Events.

    Args:
        name(str): The name of the custom action target. Can contain up to 20 characters.
        description(str): The description for the custom action target.
        id_(str): The ID for the custom action target. Can contain up to 20 alphanumeric characters.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.action_target.create(
                ctx, name=value, description=value, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.action_target.create name=value, description=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="create_action_target",
        op_kwargs={"Name": name, "Description": description, "Id": id_},
    )


async def delete(hub, ctx, action_target_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a custom action target from Security Hub. Deleting a custom action target does not affect any findings or insights that were already sent to Amazon CloudWatch Events using the custom action.

    Args:
        action_target_arn(str): The ARN of the custom action target to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.action_target.delete(ctx, action_target_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.action_target.delete action_target_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="delete_action_target",
        op_kwargs={"ActionTargetArn": action_target_arn},
    )


async def describe_all(
    hub,
    ctx,
    action_target_arns: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the custom action targets in Security Hub in your account.

    Args:
        action_target_arns(List, optional): A list of custom action target ARNs for the custom action targets to retrieve. Defaults to None.
        next_token(str, optional): The token that is required for pagination. On your first call to the DescribeActionTargets operation, set the value of this parameter to NULL. For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.action_target.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.action_target.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="describe_action_targets",
        op_kwargs={
            "ActionTargetArns": action_target_arns,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub, ctx, action_target_arn: str, name: str = None, description: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the name and description of a custom action target in Security Hub.

    Args:
        action_target_arn(str): The ARN of the custom action target to update.
        name(str, optional): The updated name of the custom action target. Defaults to None.
        description(str, optional): The updated description for the custom action target. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.action_target.update(ctx, action_target_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.action_target.update action_target_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="update_action_target",
        op_kwargs={
            "ActionTargetArn": action_target_arn,
            "Name": name,
            "Description": description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, max_results: str = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets a collection of Api resources.

    Args:
        max_results(str, optional): The maximum number of elements to be returned for this resource. Defaults to None.
        next_token(str, optional): The next page of elements from this collection. Not valid for the last element of the collection. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.apis.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.apis.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_apis",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, identity_info: Dict, user_id: str, instance_id: str) -> None:
    r"""
    **Autogenerated function**

    Updates the identity information for the specified user.  We strongly recommend limiting who has the ability to invoke UpdateUserIdentityInfo. Someone with that ability can change the login credentials of other users by changing their email address. This poses a security risk to your organization. They can change the email address of a user to the attacker's email address, and then reset the password through email. For more information, see Best Practices for Security Profiles in the Amazon Connect Administrator Guide.

    Args:
        identity_info(Dict): The identity information for the user.
        user_id(str): The identifier of the user account.
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.user.identity_info.update(
                ctx, identity_info=value, user_id=value, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.user.identity_info.update identity_info=value, user_id=value, instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="update_user_identity_info",
        op_kwargs={
            "IdentityInfo": identity_info,
            "UserId": user_id,
            "InstanceId": instance_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def copy(
    hub,
    ctx,
    source_db_cluster_snapshot_identifier: str,
    target_db_cluster_snapshot_identifier: str,
    kms_key_id: str = None,
    pre_signed_url: str = None,
    copy_tags: bool = None,
    tags: List = None,
    source_region: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Copies a snapshot of a DB cluster. To copy a DB cluster snapshot from a shared manual DB cluster snapshot, SourceDBClusterSnapshotIdentifier must be the Amazon Resource Name (ARN) of the shared DB cluster snapshot. You can copy an encrypted DB cluster snapshot from another Amazon Web Services Region. In that case, the Amazon Web Services Region where you call the CopyDBClusterSnapshot action is the destination Amazon Web Services Region for the encrypted DB cluster snapshot to be copied to. To copy an encrypted DB cluster snapshot from another Amazon Web Services Region, you must provide the following values:    KmsKeyId - The Amazon Web Services Key Management System (Amazon Web Services KMS) key identifier for the key to use to encrypt the copy of the DB cluster snapshot in the destination Amazon Web Services Region.    PreSignedUrl - A URL that contains a Signature Version 4 signed request for the CopyDBClusterSnapshot action to be called in the source Amazon Web Services Region where the DB cluster snapshot is copied from. The pre-signed URL must be a valid request for the CopyDBClusterSnapshot API action that can be executed in the source Amazon Web Services Region that contains the encrypted DB cluster snapshot to be copied. The pre-signed URL request must contain the following parameter values:    KmsKeyId - The Amazon Web Services KMS key identifier for the customer master key (CMK) to use to encrypt the copy of the DB cluster snapshot in the destination Amazon Web Services Region. This is the same identifier for both the CopyDBClusterSnapshot action that is called in the destination Amazon Web Services Region, and the action contained in the pre-signed URL.    DestinationRegion - The name of the Amazon Web Services Region that the DB cluster snapshot is to be created in.    SourceDBClusterSnapshotIdentifier - The DB cluster snapshot identifier for the encrypted DB cluster snapshot to be copied. This identifier must be in the Amazon Resource Name (ARN) format for the source Amazon Web Services Region. For example, if you are copying an encrypted DB cluster snapshot from the us-west-2 Amazon Web Services Region, then your SourceDBClusterSnapshotIdentifier looks like the following example: arn:aws:rds:us-west-2:123456789012:cluster-snapshot:aurora-cluster1-snapshot-20161115.   To learn how to generate a Signature Version 4 signed request, see  Authenticating Requests: Using Query Parameters (Amazon Web Services Signature Version 4) and  Signature Version 4 Signing Process.  If you are using an Amazon Web Services SDK tool or the CLI, you can specify SourceRegion (or --source-region for the CLI) instead of specifying PreSignedUrl manually. Specifying SourceRegion autogenerates a pre-signed URL that is a valid request for the operation that can be executed in the source Amazon Web Services Region.     TargetDBClusterSnapshotIdentifier - The identifier for the new copy of the DB cluster snapshot in the destination Amazon Web Services Region.    SourceDBClusterSnapshotIdentifier - The DB cluster snapshot identifier for the encrypted DB cluster snapshot to be copied. This identifier must be in the ARN format for the source Amazon Web Services Region and is the same value as the SourceDBClusterSnapshotIdentifier in the pre-signed URL.    To cancel the copy operation once it is in progress, delete the target DB cluster snapshot identified by TargetDBClusterSnapshotIdentifier while that DB cluster snapshot is in "copying" status. For more information on copying encrypted DB cluster snapshots from one Amazon Web Services Region to another, see  Copying a Snapshot in the Amazon Aurora User Guide.  For more information on Amazon Aurora, see  What Is Amazon Aurora? in the Amazon Aurora User Guide.   This action only applies to Aurora DB clusters.

    Args:
        source_db_cluster_snapshot_identifier(str): The identifier of the DB cluster snapshot to copy. This parameter isn't case-sensitive. You can't copy an encrypted, shared DB cluster snapshot from one Amazon Web Services Region to another. Constraints:   Must specify a valid system snapshot in the "available" state.   If the source snapshot is in the same Amazon Web Services Region as the copy, specify a valid DB snapshot identifier.   If the source snapshot is in a different Amazon Web Services Region than the copy, specify a valid DB cluster snapshot ARN. For more information, go to  Copying Snapshots Across Amazon Web Services Regions in the Amazon Aurora User Guide.    Example: my-cluster-snapshot1 .
        target_db_cluster_snapshot_identifier(str): The identifier of the new DB cluster snapshot to create from the source DB cluster snapshot. This parameter isn't case-sensitive. Constraints:   Must contain from 1 to 63 letters, numbers, or hyphens.   First character must be a letter.   Can't end with a hyphen or contain two consecutive hyphens.   Example: my-cluster-snapshot2 .
        kms_key_id(str, optional): The Amazon Web Services KMS key identifier for an encrypted DB cluster snapshot. The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the Amazon Web Services KMS customer master key (CMK). If you copy an encrypted DB cluster snapshot from your Amazon Web Services account, you can specify a value for KmsKeyId to encrypt the copy with a new Amazon Web Services KMS CMK. If you don't specify a value for KmsKeyId, then the copy of the DB cluster snapshot is encrypted with the same Amazon Web Services KMS key as the source DB cluster snapshot.  If you copy an encrypted DB cluster snapshot that is shared from another Amazon Web Services account, then you must specify a value for KmsKeyId.  To copy an encrypted DB cluster snapshot to another Amazon Web Services Region, you must set KmsKeyId to the Amazon Web Services KMS key identifier you want to use to encrypt the copy of the DB cluster snapshot in the destination Amazon Web Services Region. Amazon Web Services KMS CMKs are specific to the Amazon Web Services Region that they are created in, and you can't use CMKs from one Amazon Web Services Region in another Amazon Web Services Region. If you copy an unencrypted DB cluster snapshot and specify a value for the KmsKeyId parameter, an error is returned. Defaults to None.
        pre_signed_url(str, optional): The URL that contains a Signature Version 4 signed request for the CopyDBClusterSnapshot API action in the Amazon Web Services Region that contains the source DB cluster snapshot to copy. The PreSignedUrl parameter must be used when copying an encrypted DB cluster snapshot from another Amazon Web Services Region. Don't specify PreSignedUrl when you are copying an encrypted DB cluster snapshot in the same Amazon Web Services Region. The pre-signed URL must be a valid request for the CopyDBClusterSnapshot API action that can be executed in the source Amazon Web Services Region that contains the encrypted DB cluster snapshot to be copied. The pre-signed URL request must contain the following parameter values:    KmsKeyId - The Amazon Web Services KMS key identifier for the customer master key (CMK) to use to encrypt the copy of the DB cluster snapshot in the destination Amazon Web Services Region. This is the same identifier for both the CopyDBClusterSnapshot action that is called in the destination Amazon Web Services Region, and the action contained in the pre-signed URL.    DestinationRegion - The name of the Amazon Web Services Region that the DB cluster snapshot is to be created in.    SourceDBClusterSnapshotIdentifier - The DB cluster snapshot identifier for the encrypted DB cluster snapshot to be copied. This identifier must be in the Amazon Resource Name (ARN) format for the source Amazon Web Services Region. For example, if you are copying an encrypted DB cluster snapshot from the us-west-2 Amazon Web Services Region, then your SourceDBClusterSnapshotIdentifier looks like the following example: arn:aws:rds:us-west-2:123456789012:cluster-snapshot:aurora-cluster1-snapshot-20161115.   To learn how to generate a Signature Version 4 signed request, see  Authenticating Requests: Using Query Parameters (Amazon Web Services Signature Version 4) and  Signature Version 4 Signing Process.  If you are using an Amazon Web Services SDK tool or the CLI, you can specify SourceRegion (or --source-region for the CLI) instead of specifying PreSignedUrl manually. Specifying SourceRegion autogenerates a pre-signed URL that is a valid request for the operation that can be executed in the source Amazon Web Services Region. . Defaults to None.
        copy_tags(bool, optional): A value that indicates whether to copy all tags from the source DB cluster snapshot to the target DB cluster snapshot. By default, tags are not copied. Defaults to None.
        tags(List, optional): A list of tags. For more information, see Tagging Amazon RDS Resources in the Amazon RDS User Guide. . Defaults to None.
        source_region(str, optional): The ID of the region that contains the snapshot to be copied. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.cluster.snapshot.init.copy(
                ctx,
                source_db_cluster_snapshot_identifier=value,
                target_db_cluster_snapshot_identifier=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.cluster.snapshot.init.copy source_db_cluster_snapshot_identifier=value, target_db_cluster_snapshot_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="copy_db_cluster_snapshot",
        op_kwargs={
            "SourceDBClusterSnapshotIdentifier": source_db_cluster_snapshot_identifier,
            "TargetDBClusterSnapshotIdentifier": target_db_cluster_snapshot_identifier,
            "KmsKeyId": kms_key_id,
            "PreSignedUrl": pre_signed_url,
            "CopyTags": copy_tags,
            "Tags": tags,
            "SourceRegion": source_region,
        },
    )


async def create(
    hub,
    ctx,
    db_cluster_snapshot_identifier: str,
    db_cluster_identifier: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a snapshot of a DB cluster. For more information on Amazon Aurora, see  What Is Amazon Aurora? in the Amazon Aurora User Guide.   This action only applies to Aurora DB clusters.

    Args:
        db_cluster_snapshot_identifier(str): The identifier of the DB cluster snapshot. This parameter is stored as a lowercase string. Constraints:   Must contain from 1 to 63 letters, numbers, or hyphens.   First character must be a letter.   Can't end with a hyphen or contain two consecutive hyphens.   Example: my-cluster1-snapshot1 .
        db_cluster_identifier(str): The identifier of the DB cluster to create a snapshot for. This parameter isn't case-sensitive. Constraints:   Must match the identifier of an existing DBCluster.   Example: my-cluster1 .
        tags(List, optional): The tags to be assigned to the DB cluster snapshot. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.cluster.snapshot.init.create(
                ctx, db_cluster_snapshot_identifier=value, db_cluster_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.cluster.snapshot.init.create db_cluster_snapshot_identifier=value, db_cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="create_db_cluster_snapshot",
        op_kwargs={
            "DBClusterSnapshotIdentifier": db_cluster_snapshot_identifier,
            "DBClusterIdentifier": db_cluster_identifier,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, db_cluster_snapshot_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a DB cluster snapshot. If the snapshot is being copied, the copy operation is terminated.  The DB cluster snapshot must be in the available state to be deleted.  For more information on Amazon Aurora, see  What Is Amazon Aurora? in the Amazon Aurora User Guide.   This action only applies to Aurora DB clusters.

    Args:
        db_cluster_snapshot_identifier(str): The identifier of the DB cluster snapshot to delete. Constraints: Must be the name of an existing DB cluster snapshot in the available state.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.cluster.snapshot.init.delete(
                ctx, db_cluster_snapshot_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.cluster.snapshot.init.delete db_cluster_snapshot_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="delete_db_cluster_snapshot",
        op_kwargs={"DBClusterSnapshotIdentifier": db_cluster_snapshot_identifier},
    )


async def describe_all(
    hub,
    ctx,
    db_cluster_identifier: str = None,
    db_cluster_snapshot_identifier: str = None,
    snapshot_type: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
    include_shared: bool = None,
    include_public: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about DB cluster snapshots. This API action supports pagination. For more information on Amazon Aurora, see  What Is Amazon Aurora? in the Amazon Aurora User Guide.   This action only applies to Aurora DB clusters.

    Args:
        db_cluster_identifier(str, optional): The ID of the DB cluster to retrieve the list of DB cluster snapshots for. This parameter can't be used in conjunction with the DBClusterSnapshotIdentifier parameter. This parameter isn't case-sensitive.  Constraints:   If supplied, must match the identifier of an existing DBCluster.  . Defaults to None.
        db_cluster_snapshot_identifier(str, optional): A specific DB cluster snapshot identifier to describe. This parameter can't be used in conjunction with the DBClusterIdentifier parameter. This value is stored as a lowercase string.  Constraints:   If supplied, must match the identifier of an existing DBClusterSnapshot.   If this identifier is for an automated snapshot, the SnapshotType parameter must also be specified.  . Defaults to None.
        snapshot_type(str, optional): The type of DB cluster snapshots to be returned. You can specify one of the following values:    automated - Return all DB cluster snapshots that have been automatically taken by Amazon RDS for my Amazon Web Services account.    manual - Return all DB cluster snapshots that have been taken by my Amazon Web Services account.    shared - Return all manual DB cluster snapshots that have been shared to my Amazon Web Services account.    public - Return all DB cluster snapshots that have been marked as public.   If you don't specify a SnapshotType value, then both automated and manual DB cluster snapshots are returned. You can include shared DB cluster snapshots with these results by enabling the IncludeShared parameter. You can include public DB cluster snapshots with these results by enabling the IncludePublic parameter. The IncludeShared and IncludePublic parameters don't apply for SnapshotType values of manual or automated. The IncludePublic parameter doesn't apply when SnapshotType is set to shared. The IncludeShared parameter doesn't apply when SnapshotType is set to public. Defaults to None.
        filters(List, optional): A filter that specifies one or more DB cluster snapshots to describe. Supported filters:    db-cluster-id - Accepts DB cluster identifiers and DB cluster Amazon Resource Names (ARNs).    db-cluster-snapshot-id - Accepts DB cluster snapshot identifiers.    snapshot-type - Accepts types of DB cluster snapshots.    engine - Accepts names of database engines.  . Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so you can retrieve the remaining results.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional pagination token provided by a previous DescribeDBClusterSnapshots request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.
        include_shared(bool, optional): A value that indicates whether to include shared manual DB cluster snapshots from other Amazon Web Services accounts that this Amazon Web Services account has been given permission to copy or restore. By default, these snapshots are not included. You can give an Amazon Web Services account permission to restore a manual DB cluster snapshot from another Amazon Web Services account by the ModifyDBClusterSnapshotAttribute API action. Defaults to None.
        include_public(bool, optional): A value that indicates whether to include manual DB cluster snapshots that are public and can be copied or restored by any Amazon Web Services account. By default, the public snapshots are not included. You can share a manual DB cluster snapshot as public by using the ModifyDBClusterSnapshotAttribute API action. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.cluster.snapshot.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.cluster.snapshot.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_db_cluster_snapshots",
        op_kwargs={
            "DBClusterIdentifier": db_cluster_identifier,
            "DBClusterSnapshotIdentifier": db_cluster_snapshot_identifier,
            "SnapshotType": snapshot_type,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
            "IncludeShared": include_shared,
            "IncludePublic": include_public,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, bundle_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Get the bundle details for the requested bundle id.

    Args:
        bundle_id(str):  Unique bundle identifier. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mobile.bundle.describe(ctx, bundle_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mobile.bundle.describe bundle_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mobile",
        operation="describe_bundle",
        op_kwargs={"bundleId": bundle_id},
    )


async def export(
    hub, ctx, bundle_id: str, project_id: str = None, platform: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     Generates customized software development kit (SDK) and or tool packages used to integrate mobile web or mobile app clients with backend AWS resources.

    Args:
        bundle_id(str):  Unique bundle identifier. .
        project_id(str, optional):  Unique project identifier. . Defaults to None.
        platform(str, optional):  Developer desktop or target application platform. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mobile.bundle.export(ctx, bundle_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mobile.bundle.export bundle_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mobile",
        operation="export_bundle",
        op_kwargs={
            "bundleId": bundle_id,
            "projectId": project_id,
            "platform": platform,
        },
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

     List all available bundles.

    Args:
        max_results(int, optional):  Maximum number of records to list in a single response. . Defaults to None.
        next_token(str, optional):  Pagination token. Set to null to start listing bundles from start. If non-null pagination token is returned in a result, then pass its value in here in another request to list more bundles. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mobile.bundle.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mobile.bundle.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mobile",
        operation="list_bundles",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def remove(hub, ctx, resource_arn: str, tag_key_list: List) -> Dict:
    r"""
    **Autogenerated function**

    This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.  For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference. Removes one or more tags from the specified AWS CloudHSM resource. To remove a tag, specify only the tag key to remove (not the value). To overwrite the value for an existing tag, use AddTagsToResource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the AWS CloudHSM resource.
        tag_key_list(List): The tag key or keys to remove. Specify only the tag key to remove (not the value). To overwrite the value for an existing tag, use AddTagsToResource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsm.tags.from_resource.remove(
                ctx, resource_arn=value, tag_key_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsm.tags.from_resource.remove resource_arn=value, tag_key_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsm",
        operation="remove_tags_from_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeyList": tag_key_list},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(hub, ctx, finding_ids: List, sort_criteria: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the details of one or more findings.

    Args:
        finding_ids(List): An array of strings that lists the unique identifiers for the findings to retrieve.
        sort_criteria(Dict, optional): The criteria for sorting the results of the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.finding.init.get_all(ctx, finding_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.finding.init.get_all finding_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="get_findings",
        op_kwargs={"findingIds": finding_ids, "sortCriteria": sort_criteria},
    )


async def list_all(
    hub,
    ctx,
    finding_criteria: Dict = None,
    max_results: int = None,
    next_token: str = None,
    sort_criteria: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a subset of information about one or more findings.

    Args:
        finding_criteria(Dict, optional): The criteria to use to filter the results. Defaults to None.
        max_results(int, optional): The maximum number of items to include in each page of the response. Defaults to None.
        next_token(str, optional): The nextToken string that specifies which page of results to return in a paginated response. Defaults to None.
        sort_criteria(Dict, optional): The criteria to use to sort the results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.finding.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.finding.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="list_findings",
        op_kwargs={
            "findingCriteria": finding_criteria,
            "maxResults": max_results,
            "nextToken": next_token,
            "sortCriteria": sort_criteria,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    account_id: str,
    vault_name: str,
    upload_id: str,
    marker: str = None,
    limit: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This operation lists the parts of an archive that have been uploaded in a specific multipart upload. You can make this request at any time during an in-progress multipart upload before you complete the upload (see CompleteMultipartUpload. List Parts returns an error for completed uploads. The list returned in the List Parts response is sorted by part range.  The List Parts operation supports pagination. By default, this operation returns up to 50 uploaded parts in the response. You should always check the response for a marker at which to continue the list; if there are no more items the marker is null. To return a list of parts that begins at a specific part, set the marker request parameter to the value you obtained from a previous List Parts request. You can also limit the number of parts returned in the response by specifying the limit parameter in the request.  An AWS account has full permission to perform all operations (actions). However, AWS Identity and Access Management (IAM) users don't have any permissions by default. You must grant them explicit permission to perform specific actions. For more information, see Access Control Using AWS Identity and Access Management (IAM). For conceptual information and the underlying REST API, see Working with Archives in Amazon S3 Glacier and List Parts in the Amazon Glacier Developer Guide.

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID. .
        vault_name(str): The name of the vault.
        upload_id(str): The upload ID of the multipart upload.
        marker(str, optional): An opaque string used for pagination. This value specifies the part at which the listing of parts should begin. Get the marker value from the response of a previous List Parts response. You need only include the marker if you are continuing the pagination of results started in a previous List Parts request. Defaults to None.
        limit(str, optional): The maximum number of parts to be returned. The default limit is 50. The number of parts returned might be fewer than the specified limit, but the number of returned parts never exceeds the limit. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.part.list_all(
                ctx, account_id=value, vault_name=value, upload_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.part.list_all account_id=value, vault_name=value, upload_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="list_parts",
        op_kwargs={
            "accountId": account_id,
            "vaultName": vault_name,
            "uploadId": upload_id,
            "marker": marker,
            "limit": limit,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

     No longer used, see GetBucketNotificationConfiguration.

    Args:
        bucket(str): The name of the bucket for which to get the notification configuration.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.notification.init.get(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.notification.init.get bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_bucket_notification",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def put(
    hub,
    ctx,
    bucket: str,
    notification_configuration: Dict,
    content_md5: str = None,
    expected_bucket_owner: str = None,
) -> None:
    r"""
    **Autogenerated function**

     No longer used, see the PutBucketNotificationConfiguration operation.

    Args:
        bucket(str): The name of the bucket.
        content_md5(str, optional): The MD5 hash of the PutPublicAccessBlock request body. For requests made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is calculated automatically. Defaults to None.
        notification_configuration(Dict): The container for the configuration.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.notification.init.put(
                ctx, bucket=value, notification_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.notification.init.put bucket=value, notification_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_bucket_notification",
        op_kwargs={
            "Bucket": bucket,
            "ContentMD5": content_md5,
            "NotificationConfiguration": notification_configuration,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    dataset_id: str,
    change_type: str,
    source_type: str,
    source_params: Dict,
    format_type: str = None,
    format_params: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new changeset in a FinSpace dataset.

    Args:
        dataset_id(str): The unique identifier for the FinSpace dataset in which the changeset will be created.
        change_type(str): Option to indicate how a changeset will be applied to a dataset.    REPLACE - Changeset will be considered as a replacement to all prior loaded changesets.    APPEND - Changeset will be considered as an addition to the end of all prior loaded changesets.  .
        source_type(str): Type of the data source from which the files to create the changeset will be sourced.    S3 - Amazon S3.  .
        source_params(Dict): Source path from which the files to create the changeset will be sourced.
        format_type(str, optional): Format type of the input files being loaded into the changeset. Defaults to None.
        format_params(Dict, optional): Options that define the structure of the source file(s). Defaults to None.
        tags(Dict, optional): Metadata tags to apply to this changeset. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.finspace_data.changeset.create(
                ctx, dataset_id=value, change_type=value, source_type=value, source_params=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.finspace_data.changeset.create dataset_id=value, change_type=value, source_type=value, source_params=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="finspace-data",
        operation="create_changeset",
        op_kwargs={
            "datasetId": dataset_id,
            "changeType": change_type,
            "sourceType": source_type,
            "sourceParams": source_params,
            "formatType": format_type,
            "formatParams": format_params,
            "tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def send(
    hub,
    ctx,
    worker_id: str,
    bonus_amount: str,
    assignment_id: str,
    reason: str,
    unique_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The SendBonus operation issues a payment of money from your account to a Worker. This payment happens separately from the reward you pay to the Worker when you approve the Worker's assignment. The SendBonus operation requires the Worker's ID and the assignment ID as parameters to initiate payment of the bonus. You must include a message that explains the reason for the bonus payment, as the Worker may not be expecting the payment. Amazon Mechanical Turk collects a fee for bonus payments, similar to the HIT listing fee. This operation fails if your account does not have enough funds to pay for both the bonus and the fees.

    Args:
        worker_id(str): The ID of the Worker being paid the bonus.
        bonus_amount(str):  The Bonus amount is a US Dollar amount specified using a string (for example, "5" represents $5.00 USD and "101.42" represents $101.42 USD). Do not include currency symbols or currency codes. .
        assignment_id(str): The ID of the assignment for which this bonus is paid.
        reason(str): A message that explains the reason for the bonus payment. The Worker receiving the bonus can see this message.
        unique_request_token(str, optional): A unique identifier for this request, which allows you to retry the call on error without granting multiple bonuses. This is useful in cases such as network timeouts where it is unclear whether or not the call succeeded on the server. If the bonus already exists in the system from a previous call using the same UniqueRequestToken, subsequent calls will return an error with a message containing the request ID. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.bonus.init.send(
                ctx, worker_id=value, bonus_amount=value, assignment_id=value, reason=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.bonus.init.send worker_id=value, bonus_amount=value, assignment_id=value, reason=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="send_bonus",
        op_kwargs={
            "WorkerId": worker_id,
            "BonusAmount": bonus_amount,
            "AssignmentId": assignment_id,
            "Reason": reason,
            "UniqueRequestToken": unique_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def authorize(
    hub, ctx, account: str, cluster_identifier: str = None, vpc_ids: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Grants access to a cluster.

    Args:
        cluster_identifier(str, optional): The cluster identifier of the cluster to grant access to. Defaults to None.
        account(str): The Amazon Web Services account ID to grant access to.
        vpc_ids(List, optional): The virtual private cloud (VPC) identifiers to grant access to. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.endpoint.access.authorize(ctx, account=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.endpoint.access.authorize account=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="authorize_endpoint_access",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "Account": account,
            "VpcIds": vpc_ids,
        },
    )


async def create(
    hub,
    ctx,
    endpoint_name: str,
    subnet_group_name: str,
    cluster_identifier: str = None,
    resource_owner: str = None,
    vpc_security_group_ids: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Redshift-managed VPC endpoint.

    Args:
        cluster_identifier(str, optional): The cluster identifier of the cluster to access. Defaults to None.
        resource_owner(str, optional): The Amazon Web Services account ID of the owner of the cluster. This is only required if the cluster is in another Amazon Web Services account. Defaults to None.
        endpoint_name(str): The Redshift-managed VPC endpoint name. An endpoint name must contain 1-30 characters. Valid characters are A-Z, a-z, 0-9, and hyphen(-). The first character must be a letter. The name can't contain two consecutive hyphens or end with a hyphen.
        subnet_group_name(str): The subnet group from which Amazon Redshift chooses the subnet to deploy the endpoint.
        vpc_security_group_ids(List, optional): The security group that defines the ports, protocols, and sources for inbound traffic that you are authorizing into your endpoint. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.endpoint.access.create(
                ctx, endpoint_name=value, subnet_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.endpoint.access.create endpoint_name=value, subnet_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="create_endpoint_access",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "ResourceOwner": resource_owner,
            "EndpointName": endpoint_name,
            "SubnetGroupName": subnet_group_name,
            "VpcSecurityGroupIds": vpc_security_group_ids,
        },
    )


async def delete(hub, ctx, endpoint_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a Redshift-managed VPC endpoint.

    Args:
        endpoint_name(str): The Redshift-managed VPC endpoint to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.endpoint.access.delete(ctx, endpoint_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.endpoint.access.delete endpoint_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="delete_endpoint_access",
        op_kwargs={"EndpointName": endpoint_name},
    )


async def describe(
    hub,
    ctx,
    cluster_identifier: str = None,
    resource_owner: str = None,
    endpoint_name: str = None,
    vpc_id: str = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes a Redshift-managed VPC endpoint.

    Args:
        cluster_identifier(str, optional): The cluster identifier associated with the described endpoint. Defaults to None.
        resource_owner(str, optional): The Amazon Web Services account ID of the owner of the cluster. Defaults to None.
        endpoint_name(str, optional): The name of the endpoint to be described. Defaults to None.
        vpc_id(str, optional): The virtual private cloud (VPC) identifier with access to the cluster. Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a Marker is included in the response so that the remaining results can be retrieved. Defaults to None.
        marker(str, optional): An optional pagination token provided by a previous DescribeEndpointAccess request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by the MaxRecords parameter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.endpoint.access.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.endpoint.access.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_endpoint_access",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "ResourceOwner": resource_owner,
            "EndpointName": endpoint_name,
            "VpcId": vpc_id,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )


async def modify(
    hub, ctx, endpoint_name: str, vpc_security_group_ids: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies a Redshift-managed VPC endpoint.

    Args:
        endpoint_name(str): The endpoint to be modified.
        vpc_security_group_ids(List, optional): The complete list of VPC security groups associated with the endpoint after the endpoint is modified. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.endpoint.access.modify(ctx, endpoint_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.endpoint.access.modify endpoint_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="modify_endpoint_access",
        op_kwargs={
            "EndpointName": endpoint_name,
            "VpcSecurityGroupIds": vpc_security_group_ids,
        },
    )


async def revoke(
    hub,
    ctx,
    cluster_identifier: str = None,
    account: str = None,
    vpc_ids: List = None,
    force: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Revokes access to a cluster.

    Args:
        cluster_identifier(str, optional): The cluster to revoke access from. Defaults to None.
        account(str, optional): The Amazon Web Services account ID whose access is to be revoked. Defaults to None.
        vpc_ids(List, optional): The virtual private cloud (VPC) identifiers for which access is to be revoked. Defaults to None.
        force(bool, optional): Indicates whether to force the revoke action. If true, the Redshift-managed VPC endpoints associated with the endpoint authorization are also deleted. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.endpoint.access.revoke(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.endpoint.access.revoke
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="revoke_endpoint_access",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "Account": account,
            "VpcIds": vpc_ids,
            "Force": force,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"import_": "import"}


async def create(
    hub, ctx, key_name: str, dry_run: bool = None, tag_specifications: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a 2048-bit RSA key pair with the specified name. Amazon EC2 stores the public key and displays the private key for you to save to a file. The private key is returned as an unencrypted PEM encoded PKCS#1 private key. If a key with the specified name already exists, Amazon EC2 returns an error. You can have up to five thousand key pairs per Region. The key pair returned to you is available only in the Region in which you create it. If you prefer, you can create your own key pair using a third-party tool and upload it to any Region using ImportKeyPair. For more information, see Key Pairs in the Amazon Elastic Compute Cloud User Guide.

    Args:
        key_name(str): A unique name for the key pair. Constraints: Up to 255 ASCII characters.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        tag_specifications(List, optional): The tags to apply to the new key pair. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.key_pair.create(ctx, key_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.key_pair.create key_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_key_pair",
        op_kwargs={
            "KeyName": key_name,
            "DryRun": dry_run,
            "TagSpecifications": tag_specifications,
        },
    )


async def delete(
    hub, ctx, key_name: str = None, key_pair_id: str = None, dry_run: bool = None
) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified key pair, by removing the public key from Amazon EC2.

    Args:
        key_name(str, optional): The name of the key pair. Defaults to None.
        key_pair_id(str, optional): The ID of the key pair. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.key_pair.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.key_pair.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_key_pair",
        op_kwargs={"KeyName": key_name, "KeyPairId": key_pair_id, "DryRun": dry_run},
    )


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    key_names: List = None,
    key_pair_ids: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified key pairs or all of your key pairs. For more information about key pairs, see Key Pairs in the Amazon Elastic Compute Cloud User Guide.

    Args:
        filters(List, optional): The filters.    key-pair-id - The ID of the key pair.    fingerprint - The fingerprint of the key pair.    key-name - The name of the key pair.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.  . Defaults to None.
        key_names(List, optional): The key pair names. Default: Describes all of your key pairs. Defaults to None.
        key_pair_ids(List, optional): The IDs of the key pairs. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.key_pair.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.key_pair.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_key_pairs",
        op_kwargs={
            "Filters": filters,
            "KeyNames": key_names,
            "KeyPairIds": key_pair_ids,
            "DryRun": dry_run,
        },
    )


async def import_(
    hub,
    ctx,
    key_name: str,
    public_key_material: bytes,
    dry_run: bool = None,
    tag_specifications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Imports the public key from an RSA key pair that you created with a third-party tool. Compare this with CreateKeyPair, in which Amazon Web Services creates the key pair and gives the keys to you (Amazon Web Services keeps a copy of the public key). With ImportKeyPair, you create the key pair and give Amazon Web Services just the public key. The private key is never transferred between you and Amazon Web Services. For more information about key pairs, see Key Pairs in the Amazon Elastic Compute Cloud User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        key_name(str): A unique name for the key pair.
        public_key_material(bytes): The public key. For API calls, the text must be base64-encoded. For command line tools, base64 encoding is performed for you.
        tag_specifications(List, optional): The tags to apply to the imported key pair. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.key_pair.import(ctx, key_name=value, public_key_material=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.key_pair.import key_name=value, public_key_material=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="import_key_pair",
        op_kwargs={
            "DryRun": dry_run,
            "KeyName": key_name,
            "PublicKeyMaterial": public_key_material,
            "TagSpecifications": tag_specifications,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, flow_execution_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of objects that contain information about events in a flow execution.

    Args:
        flow_execution_id(str): The ID of the flow execution.
        next_token(str, optional): The string that specifies the next page of results. Use this when you're paginating results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.flow.execution.message.list_all(
                ctx, flow_execution_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.flow.execution.message.list_all flow_execution_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="list_flow_execution_messages",
        op_kwargs={
            "flowExecutionId": flow_execution_id,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    end_time: str,
    id_: str,
    origin_endpoint_id: str,
    s3_destination: Dict,
    start_time: str,
) -> Dict:
    r"""
        **Autogenerated function**

        Creates a new HarvestJob record.

        Args:
            end_time(str): The end of the time-window which will be harvested
    .
            id_(str): The ID of the HarvestJob. The ID must be unique within the region
    and it cannot be changed after the HarvestJob is submitted
    .
            origin_endpoint_id(str): The ID of the OriginEndpoint that the HarvestJob will harvest from.
    This cannot be changed after the HarvestJob is submitted.
    .
            s3_destination(Dict): Configuration parameters for where in an S3 bucket to place the harvested content
    .
            start_time(str): The start of the time-window which will be harvested
    .

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.mediapackage.harvest_job.create(
                    ctx,
                    end_time=value,
                    id_=value,
                    origin_endpoint_id=value,
                    s3_destination=value,
                    start_time=value,
                )

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.mediapackage.harvest_job.create end_time=value, id_=value, origin_endpoint_id=value, s3_destination=value, start_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage",
        operation="create_harvest_job",
        op_kwargs={
            "EndTime": end_time,
            "Id": id_,
            "OriginEndpointId": origin_endpoint_id,
            "S3Destination": s3_destination,
            "StartTime": start_time,
        },
    )


async def describe(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets details about an existing HarvestJob.

    Args:
        id_(str): The ID of the HarvestJob.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage.harvest_job.describe(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage.harvest_job.describe id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage",
        operation="describe_harvest_job",
        op_kwargs={"Id": id_},
    )


async def list_all(
    hub,
    ctx,
    include_channel_id: str = None,
    include_status: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a collection of HarvestJob records.

    Args:
        include_channel_id(str, optional): When specified, the request will return only HarvestJobs associated with the given Channel ID. Defaults to None.
        include_status(str, optional): When specified, the request will return only HarvestJobs in the given status. Defaults to None.
        max_results(int, optional): The upper bound on the number of records to return. Defaults to None.
        next_token(str, optional): A token used to resume pagination from the end of a previous request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage.harvest_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage.harvest_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage",
        operation="list_harvest_jobs",
        op_kwargs={
            "IncludeChannelId": include_channel_id,
            "IncludeStatus": include_status,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(hub, ctx, fleet_name: str, stack_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Associates the specified fleet with the specified stack.

    Args:
        fleet_name(str): The name of the fleet. .
        stack_name(str): The name of the stack.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.fleet.associate(
                ctx, fleet_name=value, stack_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.fleet.associate fleet_name=value, stack_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="associate_fleet",
        op_kwargs={"FleetName": fleet_name, "StackName": stack_name},
    )


async def create(
    hub,
    ctx,
    name: str,
    instance_type: str,
    compute_capacity: Dict,
    image_name: str = None,
    image_arn: str = None,
    fleet_type: str = None,
    vpc_config: Dict = None,
    max_user_duration_in_seconds: int = None,
    disconnect_timeout_in_seconds: int = None,
    description: str = None,
    display_name: str = None,
    enable_default_internet_access: bool = None,
    domain_join_info: Dict = None,
    tags: Dict = None,
    idle_disconnect_timeout_in_seconds: int = None,
    iam_role_arn: str = None,
    stream_view: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a fleet. A fleet consists of streaming instances that run a specified image.

    Args:
        name(str): A unique name for the fleet.
        image_name(str, optional): The name of the image used to create the fleet. Defaults to None.
        image_arn(str, optional): The ARN of the public, private, or shared image to use. Defaults to None.
        instance_type(str): The instance type to use when launching fleet instances. The following instance types are available:   stream.standard.small   stream.standard.medium   stream.standard.large   stream.compute.large   stream.compute.xlarge   stream.compute.2xlarge   stream.compute.4xlarge   stream.compute.8xlarge   stream.memory.large   stream.memory.xlarge   stream.memory.2xlarge   stream.memory.4xlarge   stream.memory.8xlarge   stream.memory.z1d.large   stream.memory.z1d.xlarge   stream.memory.z1d.2xlarge   stream.memory.z1d.3xlarge   stream.memory.z1d.6xlarge   stream.memory.z1d.12xlarge   stream.graphics-design.large   stream.graphics-design.xlarge   stream.graphics-design.2xlarge   stream.graphics-design.4xlarge   stream.graphics-desktop.2xlarge   stream.graphics.g4dn.xlarge   stream.graphics.g4dn.2xlarge   stream.graphics.g4dn.4xlarge   stream.graphics.g4dn.8xlarge   stream.graphics.g4dn.12xlarge   stream.graphics.g4dn.16xlarge   stream.graphics-pro.4xlarge   stream.graphics-pro.8xlarge   stream.graphics-pro.16xlarge  .
        fleet_type(str, optional): The fleet type.  ALWAYS_ON  Provides users with instant-on access to their apps. You are charged for all running instances in your fleet, even if no users are streaming apps.  ON_DEMAND  Provide users with access to applications after they connect, which takes one to two minutes. You are charged for instance streaming when users are connected and a small hourly fee for instances that are not streaming apps.  . Defaults to None.
        compute_capacity(Dict): The desired capacity for the fleet.
        vpc_config(Dict, optional): The VPC configuration for the fleet. Defaults to None.
        max_user_duration_in_seconds(int, optional): The maximum amount of time that a streaming session can remain active, in seconds. If users are still connected to a streaming instance five minutes before this limit is reached, they are prompted to save any open documents before being disconnected. After this time elapses, the instance is terminated and replaced by a new instance. Specify a value between 600 and 360000. Defaults to None.
        disconnect_timeout_in_seconds(int, optional): The amount of time that a streaming session remains active after users disconnect. If users try to reconnect to the streaming session after a disconnection or network interruption within this time interval, they are connected to their previous session. Otherwise, they are connected to a new session with a new streaming instance.  Specify a value between 60 and 360000. Defaults to None.
        description(str, optional): The description to display. Defaults to None.
        display_name(str, optional): The fleet name to display. Defaults to None.
        enable_default_internet_access(bool, optional): Enables or disables default internet access for the fleet. Defaults to None.
        domain_join_info(Dict, optional): The name of the directory and organizational unit (OU) to use to join the fleet to a Microsoft Active Directory domain. . Defaults to None.
        tags(Dict, optional): The tags to associate with the fleet. A tag is a key-value pair, and the value is optional. For example, Environment=Test. If you do not specify a value, Environment=.  If you do not specify a value, the value is set to an empty string. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following special characters:  _ . : / = + \ - @ For more information, see Tagging Your Resources in the Amazon AppStream 2.0 Administration Guide. Defaults to None.
        idle_disconnect_timeout_in_seconds(int, optional): The amount of time that users can be idle (inactive) before they are disconnected from their streaming session and the DisconnectTimeoutInSeconds time interval begins. Users are notified before they are disconnected due to inactivity. If they try to reconnect to the streaming session before the time interval specified in DisconnectTimeoutInSeconds elapses, they are connected to their previous session. Users are considered idle when they stop providing keyboard or mouse input during their streaming session. File uploads and downloads, audio in, audio out, and pixels changing do not qualify as user activity. If users continue to be idle after the time interval in IdleDisconnectTimeoutInSeconds elapses, they are disconnected. To prevent users from being disconnected due to inactivity, specify a value of 0. Otherwise, specify a value between 60 and 3600. The default value is 0.  If you enable this feature, we recommend that you specify a value that corresponds exactly to a whole number of minutes (for example, 60, 120, and 180). If you don't do this, the value is rounded to the nearest minute. For example, if you specify a value of 70, users are disconnected after 1 minute of inactivity. If you specify a value that is at the midpoint between two different minutes, the value is rounded up. For example, if you specify a value of 90, users are disconnected after 2 minutes of inactivity.  . Defaults to None.
        iam_role_arn(str, optional): The Amazon Resource Name (ARN) of the IAM role to apply to the fleet. To assume a role, a fleet instance calls the AWS Security Token Service (STS) AssumeRole API operation and passes the ARN of the role to use. The operation creates a new session with temporary credentials. AppStream 2.0 retrieves the temporary credentials and creates the appstream_machine_role credential profile on the instance. For more information, see Using an IAM Role to Grant Permissions to Applications and Scripts Running on AppStream 2.0 Streaming Instances in the Amazon AppStream 2.0 Administration Guide. Defaults to None.
        stream_view(str, optional): The AppStream 2.0 view that is displayed to your users when they stream from the fleet. When APP is specified, only the windows of applications opened by users display. When DESKTOP is specified, the standard desktop that is provided by the operating system displays. The default value is APP. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.fleet.create(
                ctx, name=value, instance_type=value, compute_capacity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.fleet.create name=value, instance_type=value, compute_capacity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="create_fleet",
        op_kwargs={
            "Name": name,
            "ImageName": image_name,
            "ImageArn": image_arn,
            "InstanceType": instance_type,
            "FleetType": fleet_type,
            "ComputeCapacity": compute_capacity,
            "VpcConfig": vpc_config,
            "MaxUserDurationInSeconds": max_user_duration_in_seconds,
            "DisconnectTimeoutInSeconds": disconnect_timeout_in_seconds,
            "Description": description,
            "DisplayName": display_name,
            "EnableDefaultInternetAccess": enable_default_internet_access,
            "DomainJoinInfo": domain_join_info,
            "Tags": tags,
            "IdleDisconnectTimeoutInSeconds": idle_disconnect_timeout_in_seconds,
            "IamRoleArn": iam_role_arn,
            "StreamView": stream_view,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified fleet.

    Args:
        name(str): The name of the fleet.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.fleet.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.fleet.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="delete_fleet",
        op_kwargs={"Name": name},
    )


async def describe_all(hub, ctx, names: List = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list that describes one or more specified fleets, if the fleet names are provided. Otherwise, all fleets in the account are described.

    Args:
        names(List, optional): The names of the fleets to describe. Defaults to None.
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.fleet.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.fleet.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="describe_fleets",
        op_kwargs={"Names": names, "NextToken": next_token},
    )


async def disassociate(hub, ctx, fleet_name: str, stack_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates the specified fleet from the specified stack.

    Args:
        fleet_name(str): The name of the fleet.
        stack_name(str): The name of the stack.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.fleet.disassociate(
                ctx, fleet_name=value, stack_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.fleet.disassociate fleet_name=value, stack_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="disassociate_fleet",
        op_kwargs={"FleetName": fleet_name, "StackName": stack_name},
    )


async def start(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Starts the specified fleet.

    Args:
        name(str): The name of the fleet.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.fleet.start(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.fleet.start name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="appstream", operation="start_fleet", op_kwargs={"Name": name}
    )


async def stop(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops the specified fleet.

    Args:
        name(str): The name of the fleet.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.fleet.stop(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.fleet.stop name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="appstream", operation="stop_fleet", op_kwargs={"Name": name}
    )


async def update(
    hub,
    ctx,
    image_name: str = None,
    image_arn: str = None,
    name: str = None,
    instance_type: str = None,
    compute_capacity: Dict = None,
    vpc_config: Dict = None,
    max_user_duration_in_seconds: int = None,
    disconnect_timeout_in_seconds: int = None,
    delete_vpc_config: bool = None,
    description: str = None,
    display_name: str = None,
    enable_default_internet_access: bool = None,
    domain_join_info: Dict = None,
    idle_disconnect_timeout_in_seconds: int = None,
    attributes_to_delete: List = None,
    iam_role_arn: str = None,
    stream_view: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified fleet. If the fleet is in the STOPPED state, you can update any attribute except the fleet name. If the fleet is in the RUNNING state, you can update the DisplayName, ComputeCapacity, ImageARN, ImageName, IdleDisconnectTimeoutInSeconds, and DisconnectTimeoutInSeconds attributes. If the fleet is in the STARTING or STOPPING state, you can't update it.

    Args:
        image_name(str, optional): The name of the image used to create the fleet. Defaults to None.
        image_arn(str, optional): The ARN of the public, private, or shared image to use. Defaults to None.
        name(str, optional): A unique name for the fleet. Defaults to None.
        instance_type(str, optional): The instance type to use when launching fleet instances. The following instance types are available:   stream.standard.small   stream.standard.medium   stream.standard.large   stream.compute.large   stream.compute.xlarge   stream.compute.2xlarge   stream.compute.4xlarge   stream.compute.8xlarge   stream.memory.large   stream.memory.xlarge   stream.memory.2xlarge   stream.memory.4xlarge   stream.memory.8xlarge   stream.memory.z1d.large   stream.memory.z1d.xlarge   stream.memory.z1d.2xlarge   stream.memory.z1d.3xlarge   stream.memory.z1d.6xlarge   stream.memory.z1d.12xlarge   stream.graphics-design.large   stream.graphics-design.xlarge   stream.graphics-design.2xlarge   stream.graphics-design.4xlarge   stream.graphics-desktop.2xlarge   stream.graphics.g4dn.xlarge   stream.graphics.g4dn.2xlarge   stream.graphics.g4dn.4xlarge   stream.graphics.g4dn.8xlarge   stream.graphics.g4dn.12xlarge   stream.graphics.g4dn.16xlarge   stream.graphics-pro.4xlarge   stream.graphics-pro.8xlarge   stream.graphics-pro.16xlarge  . Defaults to None.
        compute_capacity(Dict, optional): The desired capacity for the fleet. Defaults to None.
        vpc_config(Dict, optional): The VPC configuration for the fleet. Defaults to None.
        max_user_duration_in_seconds(int, optional): The maximum amount of time that a streaming session can remain active, in seconds. If users are still connected to a streaming instance five minutes before this limit is reached, they are prompted to save any open documents before being disconnected. After this time elapses, the instance is terminated and replaced by a new instance. Specify a value between 600 and 360000. Defaults to None.
        disconnect_timeout_in_seconds(int, optional): The amount of time that a streaming session remains active after users disconnect. If users try to reconnect to the streaming session after a disconnection or network interruption within this time interval, they are connected to their previous session. Otherwise, they are connected to a new session with a new streaming instance.  Specify a value between 60 and 360000. Defaults to None.
        delete_vpc_config(bool, optional): Deletes the VPC association for the specified fleet. Defaults to None.
        description(str, optional): The description to display. Defaults to None.
        display_name(str, optional): The fleet name to display. Defaults to None.
        enable_default_internet_access(bool, optional): Enables or disables default internet access for the fleet. Defaults to None.
        domain_join_info(Dict, optional): The name of the directory and organizational unit (OU) to use to join the fleet to a Microsoft Active Directory domain. . Defaults to None.
        idle_disconnect_timeout_in_seconds(int, optional): The amount of time that users can be idle (inactive) before they are disconnected from their streaming session and the DisconnectTimeoutInSeconds time interval begins. Users are notified before they are disconnected due to inactivity. If users try to reconnect to the streaming session before the time interval specified in DisconnectTimeoutInSeconds elapses, they are connected to their previous session. Users are considered idle when they stop providing keyboard or mouse input during their streaming session. File uploads and downloads, audio in, audio out, and pixels changing do not qualify as user activity. If users continue to be idle after the time interval in IdleDisconnectTimeoutInSeconds elapses, they are disconnected.  To prevent users from being disconnected due to inactivity, specify a value of 0. Otherwise, specify a value between 60 and 3600. The default value is 0.  If you enable this feature, we recommend that you specify a value that corresponds exactly to a whole number of minutes (for example, 60, 120, and 180). If you don't do this, the value is rounded to the nearest minute. For example, if you specify a value of 70, users are disconnected after 1 minute of inactivity. If you specify a value that is at the midpoint between two different minutes, the value is rounded up. For example, if you specify a value of 90, users are disconnected after 2 minutes of inactivity.  . Defaults to None.
        attributes_to_delete(List, optional): The fleet attributes to delete. Defaults to None.
        iam_role_arn(str, optional): The Amazon Resource Name (ARN) of the IAM role to apply to the fleet. To assume a role, a fleet instance calls the AWS Security Token Service (STS) AssumeRole API operation and passes the ARN of the role to use. The operation creates a new session with temporary credentials. AppStream 2.0 retrieves the temporary credentials and creates the appstream_machine_role credential profile on the instance. For more information, see Using an IAM Role to Grant Permissions to Applications and Scripts Running on AppStream 2.0 Streaming Instances in the Amazon AppStream 2.0 Administration Guide. Defaults to None.
        stream_view(str, optional): The AppStream 2.0 view that is displayed to your users when they stream from the fleet. When APP is specified, only the windows of applications opened by users display. When DESKTOP is specified, the standard desktop that is provided by the operating system displays. The default value is APP. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.fleet.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.fleet.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="update_fleet",
        op_kwargs={
            "ImageName": image_name,
            "ImageArn": image_arn,
            "Name": name,
            "InstanceType": instance_type,
            "ComputeCapacity": compute_capacity,
            "VpcConfig": vpc_config,
            "MaxUserDurationInSeconds": max_user_duration_in_seconds,
            "DisconnectTimeoutInSeconds": disconnect_timeout_in_seconds,
            "DeleteVpcConfig": delete_vpc_config,
            "Description": description,
            "DisplayName": display_name,
            "EnableDefaultInternetAccess": enable_default_internet_access,
            "DomainJoinInfo": domain_join_info,
            "IdleDisconnectTimeoutInSeconds": idle_disconnect_timeout_in_seconds,
            "AttributesToDelete": attributes_to_delete,
            "IamRoleArn": iam_role_arn,
            "StreamView": stream_view,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all tags for the specified resource.

    Args:
        arn(str): The ARN of the specified resource for which to list tags.
        next_token(str, optional): An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults. . Defaults to None.
        max_results(int, optional): The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.tags.list(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.tags.list arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="list_tags",
        op_kwargs={"Arn": arn, "NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    title: str,
    targets: List,
    description: str = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a pull request in the specified repository.

    Args:
        title(str): The title of the pull request. This title is used to identify the pull request to other users in the repository.
        description(str, optional): A description of the pull request. Defaults to None.
        targets(List): The targets for the pull request, including the source of the code to be reviewed (the source branch) and the destination where the creator of the pull request intends the code to be merged after the pull request is closed (the destination branch).
        client_request_token(str, optional): A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.  The AWS SDKs prepopulate client request tokens. If you are using an AWS SDK, an idempotency token is created for you. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.pull_request.init.create(
                ctx, title=value, targets=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.pull_request.init.create title=value, targets=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="create_pull_request",
        op_kwargs={
            "title": title,
            "description": description,
            "targets": targets,
            "clientRequestToken": client_request_token,
        },
    )


async def get(hub, ctx, pull_request_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a pull request in a specified repository.

    Args:
        pull_request_id(str): The system-generated ID of the pull request. To get this ID, use ListPullRequests.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.pull_request.init.get(ctx, pull_request_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.pull_request.init.get pull_request_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="get_pull_request",
        op_kwargs={"pullRequestId": pull_request_id},
    )


async def list_all(
    hub,
    ctx,
    repository_name: str,
    author_arn: str = None,
    pull_request_status: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of pull requests for a specified repository. The return list can be refined by pull request status or pull request author ARN.

    Args:
        repository_name(str): The name of the repository for which you want to list pull requests.
        author_arn(str, optional): Optional. The Amazon Resource Name (ARN) of the user who created the pull request. If used, this filters the results to pull requests created by that user. Defaults to None.
        pull_request_status(str, optional): Optional. The status of the pull request. If used, this refines the results to the pull requests that match the specified status. Defaults to None.
        next_token(str, optional): An enumeration token that, when provided in a request, returns the next batch of the results. Defaults to None.
        max_results(int, optional): A non-zero, non-negative integer used to limit the number of returned results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.pull_request.init.list_all(
                ctx, repository_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.pull_request.init.list_all repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="list_pull_requests",
        op_kwargs={
            "repositoryName": repository_name,
            "authorArn": author_arn,
            "pullRequestStatus": pull_request_status,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    application_name: str,
    runtime_environment: str,
    service_execution_role: str,
    application_description: str = None,
    application_configuration: Dict = None,
    cloud_watch_logging_options: List = None,
    tags: List = None,
    application_mode: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Kinesis Data Analytics application. For information about creating a Kinesis Data Analytics application, see Creating an Application.

    Args:
        application_name(str): The name of your application (for example, sample-app).
        application_description(str, optional): A summary description of the application. Defaults to None.
        runtime_environment(str): The runtime environment for the application (SQL-1_0, FLINK-1_6, FLINK-1_8, or FLINK-1_11).
        service_execution_role(str): The IAM role used by the application to access Kinesis data streams, Kinesis Data Firehose delivery streams, Amazon S3 objects, and other external resources.
        application_configuration(Dict, optional): Use this parameter to configure the application. Defaults to None.
        cloud_watch_logging_options(List, optional): Use this parameter to configure an Amazon CloudWatch log stream to monitor application configuration errors. . Defaults to None.
        tags(List, optional): A list of one or more tags to assign to the application. A tag is a key-value pair that identifies an application. Note that the maximum number of application tags includes system tags. The maximum number of user-defined application tags is 50. For more information, see Using Tagging. Defaults to None.
        application_mode(str, optional): Use the STREAMING mode to create a Kinesis Data Analytics Studio notebook. To create a Kinesis Data Analytics Studio notebook, use the INTERACTIVE mode. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.init.create(
                ctx, application_name=value, runtime_environment=value, service_execution_role=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.init.create application_name=value, runtime_environment=value, service_execution_role=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="create_application",
        op_kwargs={
            "ApplicationName": application_name,
            "ApplicationDescription": application_description,
            "RuntimeEnvironment": runtime_environment,
            "ServiceExecutionRole": service_execution_role,
            "ApplicationConfiguration": application_configuration,
            "CloudWatchLoggingOptions": cloud_watch_logging_options,
            "Tags": tags,
            "ApplicationMode": application_mode,
        },
    )


async def delete(hub, ctx, application_name: str, create_timestamp: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified application. Kinesis Data Analytics halts application execution and deletes the application.

    Args:
        application_name(str): The name of the application to delete.
        create_timestamp(str): Use the DescribeApplication operation to get this value.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.init.delete(
                ctx, application_name=value, create_timestamp=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.init.delete application_name=value, create_timestamp=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="delete_application",
        op_kwargs={
            "ApplicationName": application_name,
            "CreateTimestamp": create_timestamp,
        },
    )


async def describe(
    hub, ctx, application_name: str, include_additional_details: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a specific Kinesis Data Analytics application. If you want to retrieve a list of all applications in your account, use the ListApplications operation.

    Args:
        application_name(str): The name of the application.
        include_additional_details(bool, optional): Displays verbose information about a Kinesis Data Analytics application, including the application's job plan. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.init.describe(
                ctx, application_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.init.describe application_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="describe_application",
        op_kwargs={
            "ApplicationName": application_name,
            "IncludeAdditionalDetails": include_additional_details,
        },
    )


async def list_all(hub, ctx, limit: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of Kinesis Data Analytics applications in your account. For each application, the response includes the application name, Amazon Resource Name (ARN), and status.  If you want detailed information about a specific application, use DescribeApplication.

    Args:
        limit(int, optional): The maximum number of applications to list. Defaults to None.
        next_token(str, optional): If a previous command returned a pagination token, pass it into this value to retrieve the next set of results. For more information about pagination, see Using the AWS Command Line Interface's Pagination Options. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="list_applications",
        op_kwargs={"Limit": limit, "NextToken": next_token},
    )


async def rollback(
    hub, ctx, application_name: str, current_application_version_id: int
) -> Dict:
    r"""
    **Autogenerated function**

    Reverts the application to the previous running version. You can roll back an application if you suspect it is stuck in a transient status.  You can roll back an application only if it is in the UPDATING or AUTOSCALING status. When you rollback an application, it loads state data from the last successful snapshot. If the application has no snapshots, Kinesis Data Analytics rejects the rollback request. This action is not supported for Kinesis Data Analytics for SQL applications.

    Args:
        application_name(str): The name of the application.
        current_application_version_id(int): The current application version ID. You can retrieve the application version ID using DescribeApplication.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.init.rollback(
                ctx, application_name=value, current_application_version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.init.rollback application_name=value, current_application_version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="rollback_application",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
        },
    )


async def start(
    hub, ctx, application_name: str, run_configuration: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Starts the specified Kinesis Data Analytics application. After creating an application, you must exclusively call this operation to start your application.

    Args:
        application_name(str): The name of the application.
        run_configuration(Dict, optional): Identifies the run configuration (start parameters) of a Kinesis Data Analytics application. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.init.start(
                ctx, application_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.init.start application_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="start_application",
        op_kwargs={
            "ApplicationName": application_name,
            "RunConfiguration": run_configuration,
        },
    )


async def stop(hub, ctx, application_name: str, force: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Stops the application from processing data. You can stop an application only if it is in the running status, unless you set the Force parameter to true. You can use the DescribeApplication operation to find the application status.  Kinesis Data Analytics takes a snapshot when the application is stopped, unless Force is set to true.

    Args:
        application_name(str): The name of the running application to stop.
        force(bool, optional): Set to true to force the application to stop. If you set Force to true, Kinesis Data Analytics stops the application without taking a snapshot.   Force-stopping your application may lead to data loss or duplication. To prevent data loss or duplicate processing of data during application restarts, we recommend you to take frequent snapshots of your application.  You can only force stop a Flink-based Kinesis Data Analytics application. You can't force stop a SQL-based Kinesis Data Analytics application. The application must be in the STARTING, UPDATING, STOPPING, AUTOSCALING, or RUNNING status. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.init.stop(
                ctx, application_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.init.stop application_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="stop_application",
        op_kwargs={"ApplicationName": application_name, "Force": force},
    )


async def update(
    hub,
    ctx,
    application_name: str,
    current_application_version_id: int = None,
    application_configuration_update: Dict = None,
    service_execution_role_update: str = None,
    run_configuration_update: Dict = None,
    cloud_watch_logging_option_updates: List = None,
    conditional_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing Kinesis Data Analytics application. Using this operation, you can update application code, input configuration, and output configuration.  Kinesis Data Analytics updates the ApplicationVersionId each time you update your application.   You cannot update the RuntimeEnvironment of an existing application. If you need to update an application's RuntimeEnvironment, you must delete the application and create it again.

    Args:
        application_name(str): The name of the application to update.
        current_application_version_id(int, optional): The current application version ID. You must provide the CurrentApplicationVersionId or the ConditionalToken.You can retrieve the application version ID using DescribeApplication. For better concurrency support, use the ConditionalToken parameter instead of CurrentApplicationVersionId. Defaults to None.
        application_configuration_update(Dict, optional): Describes application configuration updates. Defaults to None.
        service_execution_role_update(str, optional): Describes updates to the service execution role. Defaults to None.
        run_configuration_update(Dict, optional): Describes updates to the application's starting parameters. Defaults to None.
        cloud_watch_logging_option_updates(List, optional): Describes application Amazon CloudWatch logging option updates. You can only update existing CloudWatch logging options with this action. To add a new CloudWatch logging option, use AddApplicationCloudWatchLoggingOption. Defaults to None.
        conditional_token(str, optional): A value you use to implement strong concurrency for application updates. You must provide the CurrentApplicationVersionId or the ConditionalToken. You get the application's current ConditionalToken using DescribeApplication. For better concurrency support, use the ConditionalToken parameter instead of CurrentApplicationVersionId. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.init.update(
                ctx, application_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.init.update application_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="update_application",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
            "ApplicationConfigurationUpdate": application_configuration_update,
            "ServiceExecutionRoleUpdate": service_execution_role_update,
            "RunConfigurationUpdate": run_configuration_update,
            "CloudWatchLoggingOptionUpdates": cloud_watch_logging_option_updates,
            "ConditionalToken": conditional_token,
        },
    )
